<script setup name="earlyWarningAnalysis">
import { ref, reactive, onMounted, computed, nextTick, watch, onActivated } from "vue";
import { storeToRefs } from "pinia";
import { Search, Plus } from "@element-plus/icons-vue";
import ycCard from "@/components/ycCard/index.vue";
// import addEdit from "./addEdit.vue";
import { ElMessage } from "element-plus";
import useElement from "@/hooks/useElement.js";
import { useUserStore } from '@/store/user';
import getQueryString from "@/utils/getQueryString";

import alarmParams from '@/components/pwrAlarmParams.vue';

import useStation from "@/hooks/useStationList.js";
const { provice, city, country, stationName, stationId, powerId,
  proviceList, cityList, countryList, stationList, powerList, isManual,
  getPowerList,
  whenLoaded,
} = useStation();

import powerTypes from '@/utils/const/const_powerType.js';
import { ExportFile } from '@/utils/exportFile.js';
import { useRouter } from "vue-router";
const router = useRouter();

const userStore = useUserStore();
const { uid, uname } = storeToRefs(userStore);
import moment from 'moment';


import {
  getPwrtAlmAnalyse,
  getDevAlmAnalyse,
  getBattAlmAnalyse,
  getHisRealInAlm,
  getAlmSummaryParam,
} from "@/api/alarm.js";

import {
  getPowerAlmIdType,
} from "@/api/station.js";


const { $loading, $message, $confirm } = useElement();
const flag = ref(Math.random());


const headers0 = [
  {
    prop: "fullName",
    label: "机房名称",
    width: "220",
  },
  {
    prop: "powerName",
    label: "电源名称",
    width: "80",
  },
  {
    prop: "almName",
    label: "告警名称",
    width: "160",
  },
  {
    prop: "almLevelStr",
    label: "告警等级",
    width: "120",
  },
  {
    prop: "almStartTime",
    label: "告警开始时间",
    width: "120",
  },
];

const pageNum0 = ref(1);
const pageSize0 = ref(10);
const total0 = ref(0);
const addEditVisible = ref(false);
const dialogTitle = ref("");
const datas0 = reactive({
  tableData: [],
  rowData: {},
});

const currentRow = ref({});

const alarmTypeList = ref([]);

const alarmId = ref('');

// 电源告警列表
function getList0() {
  let params = {
    almIdList: alarmId.value ? [alarmId.value] : undefined,
    provice: provice.value || undefined,
    city: city.value || undefined,
    country: country.value || undefined,
    stationId: stationId.value || undefined,
    powerId: powerId.value || undefined,
    almLevel: alarmLevel.value,
    pageNum: pageNum0.value,
    pageSize: pageSize0.value,
  };

  let loading = $loading();
  getPwrtAlmAnalyse(params).then((res) => {
    let { code, data, data2 } = res;
    let list = [];
    // let _total0 = 0;
    loading.close();
    if (code && data) {
      // console.log(data);
      list = data2.list.map(v => ({
        ...v,
        almLevelStr: ['', '一级告警', '二级告警', '三级告警', '四级告警'][v.almLevel],
        
      }));
      // _total0 = data2.total0;
    }
    datas0.tableData = list;
    // total0.value = _total0;
  })
    .catch((err) => {
      console.log(err);
    });
}

const allProps = ref([]);
// 查询属性对应关系
async function getAllProps() {
  let res = await getAlmSummaryParam();
  let { code, data, data2 } = res;
  let list = [];
  if (code && data) {
      list = data2;
    }
    allProps.value = list;
}

// 查询告警类型
async function getAlarmType() {
  let res = await getPowerAlmIdType();
  let { code, data, data2 } = res;
  let list = [];
  if (code && data) {
    Object.keys(data2).map((key) => {
      Object.keys(data2[key]).map((key2) => {
        list.push({
          value: key2,
          label: data2[key][key2]
        });
      })
    });
  }
  alarmTypeList.value = list;
}



const alarmType = ref(0);
const acTab = ref('power');
const alarmLevel = ref(1);

async function view(record) {
  let params = {
    powerId: record.powerId,
    almId: record.almId,
    startTime: record.almStartTime,
    battgroupId: record.battgroupIdList.length ? record.battgroupIdList[0] : 0,
  }
  let res = await getHisRealInAlm(params);
}


function exportExcel() {
  let _headers = headers0.map(v => {
    let prop = v.prop;
    let label = v.label;
    if (prop == 'almIsConfirmed') {
      prop = 'almIsConfirmedStr';
    }
    return {
      prop,
      label
    };
  });
  ExportFile(_headers, datas0.tableData, "电源告警");
}

// 展示数据数量
function handleSizeChange0(val) {
  pageSize0.value = val;
  getList0();
}
// 翻页
function handleCurrentChange0(val) {
  pageNum0.value = val;
  getList0();
}

async function exportExcelAll() {
  // let res = await getPwrAllAlmParam();
  // let { code, data, data2 } = res;
  // let list = [];
  // if (code && data) {
  // 		list = data2.map(v => ({
  //       ...v,
  // 			almLevelStr: ['', '一级告警', '二级告警', '三级告警', '四级告警'][v.almLevel],
  // 		}));
  // }
  // let _headers = headers0.map(v => {
  //   let prop = v.prop;
  //   let label = v.label;
  //   return {
  //     prop,
  //     label
  //   };
  // });
  // ExportFile(_headers, list, "电源告警-全部");
}


// 获取属性对应的中文名称
function getPropName(prop) {
  let name = '';
  let obj = allProps.value.filter(v => v.fieldName == prop);
  if (obj.length) {
    name = obj[0].fieldNameZh;
  }
  return name;
}

const name0 = ref('主属性曲线');
const subProp = ref([]);

subProp.value = [1];
subProp.value = [1, 2];
subProp.value = [1, 2, 3];
subProp.value = [1, 2, 3, 4];

onMounted(async () => {
  await getAlarmType();
  getAllProps();
  getList0();
});

// onActivated(async () => {
//   let pageFlag = getQueryString("pageFlag");
//   // console.log('pageFlag', pageFlag, flag.value, '=============');
//   await nextTick();
//   await whenLoaded();
  
//   if (pageFlag && pageFlag != flag.value) {
//     // let provice, city, country, stationName, battId;
    
//     if (getQueryString('stationId')) {
//       let statId = getQueryString('stationId');
//       let stat = stationList.value.find(v => v.stationId == statId);
//       if (stat) {
//         isManual.value = true;
//         stationName.value = stat.stationName;
//         await getPowerList();
//       }
//     }
//     if (getQueryString('powerId')) {
//       powerId.value = getQueryString('powerId') * 1;
//       // console.log('battId', battId.value, battList.value, '=============');
//     }
//     getList();
//     flag.value = pageFlag;
//   }
// });
</script>

<template>
  <div class="page-wrapper">
    <!-- <div class="page-header">
      </div> -->
    <div class="page-content">
      <el-tabs tab-position="left" v-model="acTab" type="card" class="main-tabs">
        <el-tab-pane name="power" class="tab-pane" label="电源告警">
          <div class="page-content-wrapper">
          <div class="page-content-tools page-filter">
            <div class="grid-container" :style="{'--counter': 9}">
              <div class="grid-item">
                <div class="label">省</div>
                <div class="value">
                  <el-select
                    v-model="provice"
                    size="small"
                    clearable
                    placeholder="请选择省"
                  >
                    <el-option
                      v-for="item in proviceList"
                      :key="'l0_' + item"
                      :label="item"
                      :value="item"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <div class="label">市</div>
                <div class="value">
                  <el-select
                    v-model="city"
                    size="small"
                    clearable
                    placeholder="请选择市"
                  >
                    <el-option
                      v-for="item in cityList"
                      :key="'l1_' + item"
                      :label="item"
                      :value="item"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <div class="label">区县</div>
                <div class="value">
                  <el-select
                    v-model="country"
                    clearable
                    size="small"
                    placeholder="请选择区县"
                  >
                    <el-option
                      v-for="item in countryList"
                      :key="'l2_' + item"
                      :label="item"
                      :value="item"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <div class="label">站点</div>
                <div class="value">
                  <el-select
                    v-model="stationName"
                    clearable
                    size="small"
                    placeholder="请选择站点"
                  >
                    <el-option
                      v-for="item in stationList"
                      :key="'l3_' + item.stationId"
                      :label="item.stationName"
                      :value="item.stationName"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <div class="label">电源名称</div>
                <div class="value">
                  <el-select
                    v-model="powerId"
                    clearable
                    size="small"
                    placeholder="请选择电源"
                  >
                    <el-option
                      v-for="item in powerList"
                      :key="'l4_' + item.powerId"
                      :label="`${item.stationName}-${item.powerName}`"
                      :value="item.powerId"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <div class="label">告警名称</div>
                <div class="value">
                  <el-select
                    v-model="alarmId"
                    size="small"
                    clearable
                    filterable
                    placeholder="请选择告警名称"
                  >
                    <el-option
                      v-for="item in alarmTypeList"
                      :key="item.value"
                      :label="item.label"
                      :value="item.value"
                    >
                    </el-option>
                  </el-select>
                </div>
              </div>
              <div class="grid-item">
                <!-- <div class="label">一级告警</div>
                <div class="label">二级告警</div>
                <div class="label">三级告警</div>
                <div class="label">四级告警</div> -->
                <el-radio-group v-model="alarmLevel" size="small" style="grid-column: span 6;">
                  <el-radio-button :label="1">一级告警</el-radio-button>
                  <el-radio-button :label="2">二级告警</el-radio-button>
                  <el-radio-button :label="3">三级告警</el-radio-button>
                  <el-radio-button :label="4">四级告警</el-radio-button>
                </el-radio-group>
              </div>
            </div>
          </div>
          <div class="page-content-table">
            <div class="pos-rel">
              <div class="pos-abs">
                <el-table
                  class="yc-table"
                  stripe
                  height="100%"
                  size="small"
                  :data="datas0.tableData"
                  style="width: 100%"
                >
                  <el-table-column
                    type="index"
                    fixed="left"
                    label="序号"
                    width="60"
                  ></el-table-column>
                  <el-table-column
                    v-for="header in headers0"
                    :key="header.prop"
                    :prop="header.prop"
                    :label="header.label"
                    :min-width="header.width"
                    align="center"
                  >
                    <template #default="scope">
                      <template v-if="header.prop == 'almIsConfirmed'">
                        <el-checkbox
                          disabled
                          :checked="scope.row[header.prop] == 1"
                        ></el-checkbox>
                      </template>
                      <template v-else>
                        {{ scope.row[header.prop] || '--' }}
                      </template>
                    </template>
                  </el-table-column>
                  <el-table-column
                    label="操作"
                    fixed="right"
                    width="120"
                    align="center"
                  >
                    <template #default="scope">
                      <el-button
                        type="warning"
                        size="small"
                        @click="view(scope.row)"
                        >查看详情</el-button
                      >
                    </template>
                  </el-table-column>
                </el-table>
              </div>
            </div>
          </div>
          <div class="page-content-page">
            <div class="page-tool">
              <el-button
                type="primary"
                round
                size="small"
                @click="getList0"
                :icon="Search"
                >查询</el-button
              >
            </div>
            <div class="el-page-container">
              <el-pagination v-model:current-page="pageNum0" v-model:page-size="pageSize0"
                :page-sizes="[20, 40, 60, 80, 100, 200, 300, 400]" size="small" layout="total, sizes, prev, pager, next, jumper" :total="total0"
                @size-change="handleSizeChange0" @current-change="handleCurrentChange0" />
            </div>
            <div class="page-tool">
              <!-- <el-button type="primary" round size="small" @click="exportExcel"
                >导出</el-button
              >
              <el-button type="primary" round size="small" @click="exportExcelAll"
                >导出全部</el-button
              > -->
            </div>
          </div>
        </div>
        </el-tab-pane>
        <el-tab-pane name="dev" label="设备告警">设备告警</el-tab-pane>
        <el-tab-pane name="batt" label="电池告警">电池告警</el-tab-pane>
      </el-tabs>
    </div>
    <div class="page-footer">
      <div class="left">
        <card :title="name0"></card>
      </div>
      <div class="right">
        <div class="btn-grp">
          <!-- <div class="item">
            <div class="label">选择电池组</div>
            <div class="value">
              <el-select
                v-model="battId"
                size="small"
                clearable
                placeholder="请选择电池组"
              >
                <el-option
                  v-for="item in battList"
                  :key="'l5_' + item.powerId"
                  :label="`${item.stationName}-${item.powerName}`"
                  :value="item.powerId"
                >
                </el-option>
              </el-select>
            </div>
          </div>
          <div class="item">
            <div class="label">设置时间周期</div>
            <div class="value">
              {{ 132 }}
            </div>
          </div>
          <div class="item">
            <div class="label">关注属性</div>
          </div> -->
        </div>
        <!-- 一个就分一块 两个就分两列一行 两个以上就两列两行 -->
        <div :class="['contain', { 'grid1': subProp.length == 1, 'grid2': subProp.length == 2, 'grid3': subProp.length > 2}]">
          <template v-for="(sub, idx) in subProp" :key="'sub_' + idx">
            <card :title="'次属性' + (idx + 1)">
              <line-chart :ref="() => chartRefs[idx]"></line-chart>
            </card>
          </template>
        </div>
      </div>
    </div>
    <!-- 弹窗 -->
    <el-dialog
      :title="dialogTitle"
      v-model="addEditVisible"
      top="0"
      draggable
      :close-on-click-modal="false"
      class="dialog-center"
      width="860px"
      center
    >
      <alarm-params
        v-if="addEditVisible"
        :type="alarmType"
        :info="currentRow"
        @change="getList"
        v-model:visible="addEditVisible"
      ></alarm-params>
    </el-dialog>
  </div>
</template>

<style scoped lang="less">
.page-wrapper {
  display: flex;
  flex-direction: column;
  padding: 8px;
  height: 100%;

  .page-content {
    flex: 1;
    .main-tabs {
      height: 100%;
      :deep(.el-tabs__header) {

        border-bottom: 0 none;
      }
      :deep(.el-tabs__header) {
         .el-tabs__nav {
            border: 0 none;
          }
        .el-tabs__item {
          background: #21487e;
          color: #fff;
          border: 0 none;
          &.is-active {
            background: #409EFF;
          }
        }
      }
    }
  }
  .page-footer {
    flex: 2;
    display: flex;
    .left {
      flex: 1;
    }
    .right {
      flex: 1.6;
      margin-left: 10px;
      display: flex;
      flex-direction: column;
      .btn-grp {
        display: flex;
        justify-content: flex-end;
        padding: 8px;
      }
      .contain {
        flex: 1;
        display: grid;
        grid-column-gap: 8px;
        grid-row-gap: 8px;
        &.grid1 {
          grid-template-columns: repeat(1, 1fr);
        }
        &.grid2 {
          grid-template-columns: repeat(2, 1fr);
          grid-template-rows: repeat(1, 1fr);
        }
        &.grid3 {
          grid-template-columns: repeat(2, 1fr);
          grid-template-rows: repeat(2, 1fr);
        }
      }
    }
  }
  .tab-pane {
    height: 100%;
  }
}

.page-content-wrapper {
  display: flex;
  flex-direction: column;
  height: 100%;

  .page-content-tools {
    padding-bottom: 8px;

    .flex-row {
      display: flex;
      align-items: center;

      :deep(.el-checkbox) {
        color: #fff;
      }

      .group {
        margin-left: 30px;
      }
    }
  }

  .page-content-table {
    // border-top: 1px solid var(--border-light-color);
    box-sizing: border-box;
    flex: 1;
    margin-left: 26px;
    margin-right: 26px;
  }

  .page-content-page {
    padding: 8px 8px 0 8px;
    text-align: center;

    .el-page-container {
      display: inline-block;
      padding: 0 16px;
    }

    .page-tool {
      display: inline-block;
    }
  }
}

.hdw-card-container {
  width: 240px;
  padding-right: 8px;
  height: 100%;
}

.pos-rel {
  position: relative;
  width: 100%;
  height: 100%;

  .pos-abs {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    width: 100%;
    height: 100%;
  }
}

.tools-filter {
  display: inline-block;
  font-size: 14px;

  .tools-filter-item {
    display: inline-block;
    margin-right: 8px;

    .filter-label {
      display: inline-block;
    }

    .filter-content {
      display: inline-block;
    }
  }
}
</style>
